AnnotationFlags

Struct AnnotationFlags 

pub struct AnnotationFlags(/* private fields */);
Annotation flags (ISO 32000-2 section 12.5.3, Table 165).

The flags are stored as a 32-bit integer where each bit has a specific meaning defined by the specification.

Implementations

Source

impl AnnotationFlags

pub fn from_bits(bits: u32) -> Self

Create flags from a raw integer value.

pub fn bits(&self) -> u32

Get the raw bits.

pub fn invisible(&self) -> bool

Bit 1: If set, do not display the annotation if it does not belong to one of the standard annotation types.

pub fn hidden(&self) -> bool

Bit 2: If set, do not display or print the annotation.

pub fn print(&self) -> bool

Bit 3: If set, print the annotation when the page is printed.

pub fn no_zoom(&self) -> bool

Bit 4: If set, do not scale the annotation’s appearance to match the magnification of the page.

pub fn no_rotate(&self) -> bool

Bit 5: If set, do not rotate the annotation’s appearance to match the rotation of the page.

pub fn no_view(&self) -> bool

Bit 6: If set, do not display the annotation on the screen.

pub fn read_only(&self) -> bool

Bit 7: If set, the annotation is read-only.

pub fn locked(&self) -> bool

Bit 8: If set, do not allow the annotation to be deleted or modified.

pub fn toggle_no_view(&self) -> bool

Bit 9: If set, invert the NoView flag when the cursor enters/exits the annotation’s bounding box.

pub fn locked_contents(&self) -> bool

Bit 10: If set, the annotation’s contents cannot be changed while the annotation is locked.

pub fn is_visible(&self) -> bool

Returns true if the annotation should be visible for screen display.