DocError

Enum DocError 

pub enum DocError {
    MissingKey(String),
    UnexpectedType,
    Parser(String),
    DepthExceeded,
    ValueTooLong {
        len: usize,
        max: u32,
    },
    TypeMismatch {
        expected: String,
        got: String,
    },
    InvalidChoiceIndex {
        index: usize,
        count: usize,
    },
    FieldNotFound(String),
    InvalidIndex(usize),
    NotFound(String),
    NotSupported(String),
}
Errors that can occur during document structure parsing.

Variants



MissingKey(String)

A required dictionary key is missing.



UnexpectedType

An object had an unexpected type.



Parser(String)

An error propagated from the parser layer.



DepthExceeded

A tree or linked-list traversal exceeded the maximum allowed depth.



ValueTooLong

The provided value exceeds the field’s maximum length.

Fields

len: usize

Actual length of the value.

max: u32

Maximum allowed length.



TypeMismatch

The provided value is not valid for the target field type.

Fields

expected: String

The expected value kind.

got: String

The actual value kind.



InvalidChoiceIndex

A choice index is out of range.

Fields

index: usize

The requested index.

count: usize

The number of available options.



FieldNotFound(String)

The named field was not found in the form.



InvalidIndex(usize)

An index was out of range.



NotFound(String)

The requested named entry was not found.



NotSupported(String)

The requested operation is not supported.

Not Supported

Returned by mutation APIs that are intentionally stubbed out because rpdfium is a read-only library (per ADR-017). The contained string describes the unsupported operation.