pub enum ScaleMethod {
Always,
Bigger,
Smaller,
Never,
}Expand description
Icon scale method (from /SW key in IconFit dictionary).
Variants
Always
Always scale to fit (A, default).
Bigger
Scale only if the icon is bigger than the annotation (B).
Smaller
Scale only if the icon is smaller than the annotation (S).
Never
Never scale (N).