Module struct_element

Module struct_element 

Structure element — CPDF_StructElement.

A single node in the tagged PDF structure tree, carrying semantic information such as type tag, alternative text, language, attributes, and marked content IDs (ISO 32000-2 section 14.7.2).

Tree building is in crate::struct_tree (corresponds to CPDF_StructTree).

Structs

StructAttribute
A single attribute dictionary associated with a structure element.
StructElement
A single node in the structure tree.

Enums

AttributeValue
A value in a structure attribute dictionary.