pub struct McidMapping { /* private fields */ }Expand description
Mapping from (page ObjectId, MCID) to structure element information.
Built by walking the structure tree and collecting all MCID associations.
Implementations
Sourceimpl McidMapping
impl McidMapping
Sourcepub fn from_struct_tree(tree: &StructTree) -> Self
pub fn from_struct_tree(tree: &StructTree) -> Self
Build an MCID mapping by iteratively walking the structure tree.
Sourcepub fn element_for_mcid(
&self,
page_id: ObjectId,
mcid: i64,
) -> Option<&StructElement>
pub fn element_for_mcid( &self, page_id: ObjectId, mcid: i64, ) -> Option<&StructElement>
Look up the structure element for a given page and MCID.