pub enum AnnotationType {
Show 29 variants
Text,
Link,
FreeText,
Line,
Square,
Circle,
Polygon,
PolyLine,
Highlight,
Underline,
Squiggly,
StrikeOut,
Stamp,
Caret,
Ink,
Popup,
FileAttachment,
Sound,
Widget,
Movie,
Screen,
PrinterMark,
TrapNet,
Watermark,
ThreeD,
RichMedia,
XFAWidget,
Redact,
Other,
}Expand description
Annotation subtypes defined by the PDF specification.
Variants
Text
Text (sticky note) annotation.
Link
Link annotation.
FreeText
Free text annotation.
Line
Line annotation.
Square
Square annotation.
Circle
Circle annotation.
Polygon
Polygon annotation.
PolyLine
Polyline annotation.
Highlight
Highlight markup annotation.
Underline
Underline markup annotation.
Squiggly
Squiggly underline markup annotation.
StrikeOut
Strikeout markup annotation.
Stamp
Stamp annotation.
Caret
Caret annotation.
Ink
Ink annotation.
Popup
Popup annotation.
FileAttachment
File attachment annotation.
Sound
Sound annotation.
Widget
Widget annotation (form field).
Movie
Movie annotation.
Screen
Screen annotation.
PrinterMark
Printer’s mark annotation.
TrapNet
Trap network annotation.
Watermark
Watermark annotation.
ThreeD
3D annotation.
RichMedia
Rich media annotation.
XFAWidget
XFA widget annotation.
Redact
Redaction annotation.
Other
Unrecognized annotation subtype.
Implementations
Sourceimpl AnnotationType
impl AnnotationType
Sourcepub fn supports_ap_objects(&self) -> bool
pub fn supports_ap_objects(&self) -> bool
Returns true if this annotation subtype supports appearance stream (AP)
object manipulation via FPDFAnnot_AppendObject etc.
The supported subtypes are: Stamp, FreeText, Ink, Square, Circle, Polygon, PolyLine, Line, Highlight, Underline, Squiggly, StrikeOut.
Corresponds to FPDFAnnot_IsObjectSupportedSubtype().
Sourcepub fn annot_is_object_supported_subtype(&self) -> bool
pub fn annot_is_object_supported_subtype(&self) -> bool
ADR-019 alias for Self::supports_ap_objects().
Corresponds to FPDFAnnot_IsObjectSupportedSubtype().
Sourcepub fn is_object_supported_subtype(&self) -> bool
👎Deprecated since 0.1.0: use annot_is_object_supported_subtype() instead
pub fn is_object_supported_subtype(&self) -> bool
use annot_is_object_supported_subtype() instead
Deprecated: use annot_is_object_supported_subtype() instead.
Sourcepub fn is_ap_object_supported(&self) -> bool
👎Deprecated since 0.1.0: use annot_is_object_supported_subtype() instead
pub fn is_ap_object_supported(&self) -> bool
use annot_is_object_supported_subtype() instead
Deprecated: use annot_is_object_supported_subtype() instead.
Sourcepub fn is_supported_for_creation(&self) -> bool
pub fn is_supported_for_creation(&self) -> bool
Returns whether this annotation subtype is currently supported for creation.
Currently supported subtypes: circle, fileattachment, freetext, highlight, ink, link, popup, square, squiggly, stamp, strikeout, text, underline.
Corresponds to FPDFAnnot_IsSupportedSubtype.
Sourcepub fn annot_is_supported_subtype(&self) -> bool
pub fn annot_is_supported_subtype(&self) -> bool
ADR-019 alias for Self::is_supported_for_creation().
Corresponds to FPDFAnnot_IsSupportedSubtype.
Sourcepub fn is_supported_subtype(&self) -> bool
👎Deprecated since 0.1.0: use annot_is_supported_subtype() instead
pub fn is_supported_subtype(&self) -> bool
use annot_is_supported_subtype() instead
Deprecated: use annot_is_supported_subtype() instead.