pub struct AnnotationFlags(/* private fields */);Expand description
Annotation flags (ISO 32000-2 section 12.5.3, Table 165).
The flags are stored as a 32-bit integer where each bit has a specific meaning defined by the specification.
Implementations
Sourceimpl AnnotationFlags
impl AnnotationFlags
Sourcepub fn invisible(&self) -> bool
pub fn invisible(&self) -> bool
Bit 1: If set, do not display the annotation if it does not belong to one of the standard annotation types.
Bit 2: If set, do not display or print the annotation.
Sourcepub fn no_zoom(&self) -> bool
pub fn no_zoom(&self) -> bool
Bit 4: If set, do not scale the annotation’s appearance to match the magnification of the page.
Sourcepub fn no_rotate(&self) -> bool
pub fn no_rotate(&self) -> bool
Bit 5: If set, do not rotate the annotation’s appearance to match the rotation of the page.
Sourcepub fn locked(&self) -> bool
pub fn locked(&self) -> bool
Bit 8: If set, do not allow the annotation to be deleted or modified.
Sourcepub fn toggle_no_view(&self) -> bool
pub fn toggle_no_view(&self) -> bool
Bit 9: If set, invert the NoView flag when the cursor enters/exits the annotation’s bounding box.
Sourcepub fn locked_contents(&self) -> bool
pub fn locked_contents(&self) -> bool
Bit 10: If set, the annotation’s contents cannot be changed while the annotation is locked.
Sourcepub fn is_visible(&self) -> bool
pub fn is_visible(&self) -> bool
Returns true if the annotation should be visible for screen display.