pub struct FormFieldFlags(/* private fields */);Expand description
Form field flag bits (/Ff).
ISO 32000-1:2008, Tables 8.70 (common), 8.75 (button), 8.77 (text), 8.79 (choice). Multiple groups share bit positions because the meaning depends on the field type (e.g. bit 23 is both DoNotSpellCheck for text and DoNotSpellCheck for choice).
Implementations
Sourceimpl FormFieldFlags
impl FormFieldFlags
Sourcepub fn is_read_only(self) -> bool
pub fn is_read_only(self) -> bool
Bit 1: Field is read-only.
Sourcepub fn is_required(self) -> bool
pub fn is_required(self) -> bool
Bit 2: Field must have a value before the document is submitted.
Sourcepub fn is_no_export(self) -> bool
pub fn is_no_export(self) -> bool
Bit 3: Field value must not be exported.
Sourcepub fn is_no_toggle_to_off(self) -> bool
pub fn is_no_toggle_to_off(self) -> bool
Bit 15: Radio button — at least one must be selected at all times.
Bit 17: Field is a pushbutton (not a checkbox or radio button).
Sourcepub fn is_radios_in_unison(self) -> bool
pub fn is_radios_in_unison(self) -> bool
Bit 26: Radio buttons with the same value turn on/off together.
(Button fields. Note: same bit as is_rich_text for text fields.)
Sourcepub fn is_multiline(self) -> bool
pub fn is_multiline(self) -> bool
Bit 13: Text field allows multiple lines.
Sourcepub fn is_password(self) -> bool
pub fn is_password(self) -> bool
Bit 14: Text field is a password (display as bullets).
Sourcepub fn is_file_select(self) -> bool
pub fn is_file_select(self) -> bool
Bit 21: Text field value is a file-select path.
Sourcepub fn is_do_not_spell_check(self) -> bool
pub fn is_do_not_spell_check(self) -> bool
Bit 23: Text/choice field should not be spell-checked.
Sourcepub fn is_do_not_scroll(self) -> bool
pub fn is_do_not_scroll(self) -> bool
Bit 24: Text field should not scroll horizontally.
Sourcepub fn is_rich_text(self) -> bool
pub fn is_rich_text(self) -> bool
Bit 26: Text field contains rich text (RV entry).
(Text fields. Note: same bit as is_radios_in_unison for button fields.)
Sourcepub fn is_combo_editable(self) -> bool
pub fn is_combo_editable(self) -> bool
Bit 19: Combo box choice field is editable by the user.
Sourcepub fn is_multi_select(self) -> bool
pub fn is_multi_select(self) -> bool
Bit 22: List box allows multiple simultaneous selections.
Sourcepub fn is_commit_on_sel_change(self) -> bool
pub fn is_commit_on_sel_change(self) -> bool
Bit 27: Choice field commits the value immediately on selection change.
Sourcepub fn set_read_only(&mut self, v: bool)
pub fn set_read_only(&mut self, v: bool)
Set or clear the read-only flag (bit 1).
Sourcepub fn set_required(&mut self, v: bool)
pub fn set_required(&mut self, v: bool)
Set or clear the required flag (bit 2).
Sourcepub fn set_no_export(&mut self, v: bool)
pub fn set_no_export(&mut self, v: bool)
Set or clear the no-export flag (bit 3).